summaryrefslogtreecommitdiff
path: root/InCallUI/src/com/android/incallui/InCallPresenter.java
diff options
context:
space:
mode:
authorSantos Cordon <santoscordon@google.com>2014-01-30 05:51:06 -0800
committerBaligh Uddin <baligh@google.com>2014-02-20 15:06:55 -0800
commitdd81d5dcff06d1ea940051fd535adeecae63a746 (patch)
tree256d1a63cfc700c8d829107a97cbbf10be816714 /InCallUI/src/com/android/incallui/InCallPresenter.java
parentc07366f82b7a38f48f1f17c3f7b9b274e4d36b34 (diff)
OutgoingCalls(4/6) - Connecting the in-call disconnect button with Telecomm.
In-call app now sends appropriate disconnect command when user clicks the end-call button. Change-Id: I3da99827ce068566ca9e72d69c0375f0409a8014
Diffstat (limited to 'InCallUI/src/com/android/incallui/InCallPresenter.java')
-rw-r--r--InCallUI/src/com/android/incallui/InCallPresenter.java12
1 files changed, 8 insertions, 4 deletions
diff --git a/InCallUI/src/com/android/incallui/InCallPresenter.java b/InCallUI/src/com/android/incallui/InCallPresenter.java
index 98393cf90..16d22ed14 100644
--- a/InCallUI/src/com/android/incallui/InCallPresenter.java
+++ b/InCallUI/src/com/android/incallui/InCallPresenter.java
@@ -58,7 +58,7 @@ public class InCallPresenter implements CallList.Listener {
private boolean mServiceConnected = false;
/** Used to send call-related commands and updates back to Telecomm. */
- private IInCallAdapter mInCallAdapter;
+ private IInCallAdapter mTelecommAdapter;
/**
* Is true when the activity has been previously started. Some code needs to know not just if
@@ -528,10 +528,14 @@ public class InCallPresenter implements CallList.Listener {
/**
* Persists the current instance of IInCallAdapter.
*
* @param inCallAdapter The adapter to Telecomm system used to send call-related commands.
*/
- void setInCallAdapter(IInCallAdapter inCallAdapter) {
- mInCallAdapter = inCallAdapter;
+ void setTelecommAdapter(IInCallAdapter telecommAdapter) {
+ mTelecommAdapter = telecommAdapter;
+ }
+
+ IInCallAdapter getTelecommAdapter() {
+ return mTelecommAdapter;
}
/**
@@ -528,10 +528,14 @@ public class InCallPresenter implements CallList.Listener {
* Persists the current instance of IInCallAdapter.
*
- * @param inCallAdapter The adapter to Telecomm system used to send call-related commands.
+ * @param telecommAdapter The adapter to the Telecomm system used to send call-related commands.
*/